==> transmission-0.90.tar.bz2: transmission-0.90/macosx/PiecesView.h <==
/******************************************************************************
 * $Id: PiecesView.h 3083 2007-09-16 01:02:06Z livings124 $
 *
 * Copyright (c) 2006-2007 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import "Torrent.h"

@interface PiecesView : NSImageView
{
    int8_t  * fPieces;
    
    NSImage * fBack;
    NSColor * fWhiteColor, * fBlueColor, * fOrangeColor,
            * fGreen1Color, * fGreen2Color, * fGreen3Color,
            * fBlue1Color, * fBlue2Color, * fBlue3Color, * fBlue4Color;
    
    Torrent * fTorrent;
    int fNumPieces, fAcross, fWidth, fExtraBorder;
}

- (void) setTorrent: (Torrent *) torrent;
- (void) updateView: (BOOL) first;

@end

==> transmission-1.51.tar.bz2: transmission-1.51/macosx/PiecesView.h <==
/******************************************************************************
 * $Id: PiecesView.h 7007 2008-11-01 15:22:32Z livings124 $
 *
 * Copyright (c) 2006-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>

@class Torrent;

@interface PiecesView : NSImageView
{
    int8_t  * fPieces;
    
    NSImage * fBack;
    NSColor * fGreenAvailabilityColor, * fBluePieceColor;
    
    Torrent * fTorrent;
    NSInteger fNumPieces, fAcross, fWidth, fExtraBorder;
}

- (void) setTorrent: (Torrent *) torrent;

- (void) clearView;
- (void) updateView;

@end
